@@ -257,7 +257,7 @@ def get_value_from_array(data_arr_input, low_li, up_li):
 
 def main():
     parser = argparse.ArgumentParser(prog='vinset', description='VINSET package.')
-    parser.add_argument('--version', action='version', version='3.0.3'),
+    parser.add_argument('--version', action='version', version='3.0.4'),
     parser.add_argument("-i", dest="input_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="input mp4 file", metavar="filename.mp4")
     parser.add_argument("-d", dest="input_data_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
@@ -653,7 +653,11 @@ def main():
                                 pointer_position_tuple = pointer_info_dict[pointer_position_info_name]
                                 pointer_x = pointer_position_tuple[0]
                                 pointer_y = pointer_position_tuple[1]
-                                cv2.circle(clone_frame, (pointer_x, pointer_y), pointer_radius, pointer_color, -1)
+                                if pointer_x == ax_x or pointer_x == (ax_x + ax_w) or \
+                                        pointer_y == ax_y or pointer_y == (ax_y - ax_h):
+                                    pass
+                                else:
+                                    cv2.circle(clone_frame, (pointer_x, pointer_y), pointer_radius, pointer_color, -1)
 
                         elif show_type == "static" and parent_index is not None:
                             ax_pos = axes_info["position"]
@@ -722,7 +726,11 @@ def main():
                                 pointer_position_tuple = pointer_info_dict[pointer_position_info_name]
                                 pointer_x = pointer_position_tuple[0]
                                 pointer_y = pointer_position_tuple[1]
-                                cv2.circle(clone_frame, (pointer_x, pointer_y), pointer_radius, pointer_color, -1)
+                                if pointer_x == ax_x or pointer_x == (ax_x + ax_w) or \
+                                        pointer_y == ax_y or pointer_y == (ax_y - ax_h):
+                                    pass
+                                else:
+                                    cv2.circle(clone_frame, (pointer_x, pointer_y), pointer_radius, pointer_color, -1)
 
                     else:
                         print("\r")
